==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Añadir propiedad personalizada</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translatorcomment>--exact match--
--file: es.po--
Nombre del Bloque:
Nombre de capa:</translatorcomment>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Valor:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translatorcomment>--exact match--
--file: es.po--
Tipo de línea:</translatorcomment>
        <translation type="obsolete">Tipo:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+348"/>
        <source>Geometry</source>
        <translation>Geometría</translation>
    </message>
    <message>
        <location line="+277"/>
        <source>Add custom property to selected objects</source>
        <translation>Agregar una propiedad personalizada a los objetos seleccionados</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Izquierda</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="obsolete">Centro</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Derecha</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translation type="obsolete">Alineado</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">Parte superior</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Medio</translation>
    </message>
    <message>
        <location line="-435"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>*VARIA*</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>:</source>
        <translatorcomment>--exact match--
--file: artisan_es.ts--
Documento cargado:
Versión:</translatorcomment>
        <translation>:</translation>
    </message>
    <message>
        <location line="+137"/>
        <source>No Selection</source>
        <translatorcomment>--exact match--
--file: sketch_es.po--
Ajusta el lienzo al tamaño de la selección o del dibujo si no hay selección
Seleccin nula</translatorcomment>
        <translation>Seleccin nula</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Dependent Entities</source>
        <translation>Entidades dependientes</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location line="+135"/>
        <source>Index</source>
        <translatorcomment>--exact match--
--file: qgis_es.ts--
Índice
Valor indexado</translatorcomment>
        <translation>Índice</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Retire esta propiedad de los objetos seleccionados</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>All</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Mosaico &amp;horizontal
Mosaico horizontal
¿Realmente quiere cerrar el fichero
%1?</translatorcomment>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Añadir propiedad personalizada</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Encajar en la página
Primer punto de ajuste</translatorcomment>
        <translation type="obsolete">Ajuste</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">Parte inferior</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--google--
Dibuje arcos tangenciales a su base
Especifique la etnidad base
Seleccione entidad base</translatorcomment>
        <translation type="obsolete">Base</translation>
    </message>
    <message>
        <location line="+157"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location line="+119"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Utilizar la medición automática</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location line="+317"/>
        <location line="+12"/>
        <source>Property Editor</source>
        <translation>Editor de propiedades</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: grassmods_es.po--</translatorcomment>
        <translation>Selección:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location line="+163"/>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Mueve la selección a una nueva capa</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Handle:</source>
        <translatorcomment>--ignored colon--
--file: es.po--</translatorcomment>
        <translation>Tirador:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Añadir propiedad personalizada</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translatorcomment>--exact match--
--file: es.po--
Nombre del Bloque:
Nombre de capa:</translatorcomment>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Valor:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translatorcomment>--exact match--
--file: es.po--
Tipo de línea:</translatorcomment>
        <translation type="obsolete">Tipo:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <source>Geometry</source>
        <translation type="vanished">Geometría</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.js" line="+704"/>
        <source>Add custom property to selected objects</source>
        <translation>Agregar una propiedad personalizada a los objetos seleccionados</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Izquierda</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="obsolete">Centro</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Derecha</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translation type="obsolete">Alineado</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">Parte superior</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Medio</translation>
    </message>
    <message>
        <location line="+614"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>*VARIA*</translation>
    </message>
    <message>
        <location line="-1130"/>
        <source>:</source>
        <translatorcomment>--exact match--
--file: artisan_es.ts--
Documento cargado:
Versión:</translatorcomment>
        <translation>:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translatorcomment>--exact match--
--file: sketch_es.po--
Ajusta el lienzo al tamaño de la selección o del dibujo si no hay selección
Seleccin nula</translatorcomment>
        <translation>Seleccin nula</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Propiedades específicas</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Entidades dependientes</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translatorcomment>--exact match--
--file: qgis_es.ts--
Índice
Valor indexado</translatorcomment>
        <translation>Índice</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Retire esta propiedad de los objetos seleccionados</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Mosaico &amp;horizontal
Mosaico horizontal
¿Realmente quiere cerrar el fichero
%1?</translatorcomment>
        <translation>Todo</translation>
    </message>
    <message>
        <location line="+639"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Añadir propiedad personalizada</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Encajar en la página
Primer punto de ajuste</translatorcomment>
        <translation type="obsolete">Ajuste</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">Parte inferior</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--google--
Dibuje arcos tangenciales a su base
Especifique la etnidad base
Seleccione entidad base</translatorcomment>
        <translation type="obsolete">Base</translation>
    </message>
    <message>
        <location line="-481"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location line="+121"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Utilizar la medición automática</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Editor de propiedades</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: grassmods_es.po--</translatorcomment>
        <translation>Selección:</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">General</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Propiedades generales</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Mueve la selección a una nueva capa</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Escala de tipo de línea:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Protegida:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translatorcomment>--ignored colon--
--file: es.po--</translatorcomment>
        <translation>Tirador:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Visualizar coordenadas z</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Mostrar las propiedades del bloque actual y la capa actual</translation>
    </message>
</context>
</TS>
